var gulp = require('gulp'),
    browserSync = require('browser-sync').create(),
    nunjucksRender = require('gulp-nunjucks-render'),
    htmlbeautify = require('gulp-html-beautify'),
    plumber = require('gulp-plumber'),
    sass = require('gulp-sass'),
    sourcemaps = require('gulp-sourcemaps'),
    autoprefixer = require('gulp-autoprefixer'),
    gcmq = require('gulp-group-css-media-queries'),
    csso = require('gulp-csso'),
    argv = require('yargs').argv,
    gulpif = require('gulp-if'),
    uglify = require('gulp-uglify'),
    concat = require('gulp-concat'),
    // svg, jpg, png img min
    imagemin = require('gulp-imagemin'),
    //Svg sprites & inliner
    svgSprite = require('gulp-svg-sprite'),
    sassInlineSvg = require('gulp-sass-inline-svg'),
    //Rename
    rename = require("gulp-rename"),
    del = require('del'),
    //setup
    jsonCss = require('gulp-json-css'),
    //Json
    fs = require('fs'),
    path = require('path'),
    data = require('gulp-data'),
    gulpSequence = require('gulp-sequence'),
    source = require('vinyl-source-stream'),
    vinylBuffer = require('vinyl-buffer'),
    htmlReaplce = require('gulp-html-replace');

function getFolders(dir) {
    return fs.readdirSync(dir);
}

var root = {
    dev: 'dev/',
    build: 'build/'
};

var dev = {
    root: root.dev,
    src: root.dev + 'src/',
    helpers: root.dev + 'src/cumo/helpers/',
    nunjucks: root.dev + 'src/pages',
    icons: root.dev + 'icons',
    favicon: root.dev + 'favicon'
};

var build = {
    root: root.build,
    styles: root.build + 'css/',
    images: root.build + 'images',
    icons: root.build + 'images/icons',
    icons_optimized: root.build + 'images/icons/optimized'
};

// Setup file
gulp.task('cumo', function() {
    delete require.cache[require.resolve('./cumo.js')];

    var stream = source('cumo.json'),
        streamEnd = stream,
        cumoConfig = require('./cumo.js'),
        jsonConfig = JSON.stringify(cumoConfig);

    stream.write(jsonConfig);

    process.nextTick(function() {
        // in the next process cycle, end the stream
        stream.end();
    });

    streamEnd = streamEnd
        .pipe(vinylBuffer())
        .pipe(jsonCss({
            keepObjects: true
        }))
        .pipe(concat('_variables.scss'))
        .pipe(gulp.dest(dev.helpers));
});


// Styles
gulp.task('styles', function () {
    return gulp.src(dev.src + 'styles.scss')
        .pipe(plumber())
        .pipe(sourcemaps.init())
        .pipe(sass({
            includePaths: require('node-normalize-scss').includePaths
        }).on('error', sass.logError))
        .pipe(autoprefixer({
            browsers: ['> 5%', 'last 5 versions'],
            cascade: false
        }))
        .pipe(gcmq())
        .pipe(gulpif(
            argv.prod,
            csso({
                restructure: false,
                sourceMap: false,
                debug: false
            })
        ))
        .pipe(gulpif(
            argv.prod,
            rename("style.min.css")
        ))
        .pipe(sourcemaps.write('.'))
        .pipe(gulp.dest(build.styles));
});


// Docs Html Templates
gulp.task('nunja-docs', function () {
    var pages = getFolders(dev.src + 'cumo/pages');
    var icons = getFolders(dev.icons + '/sprite');
    var cumoConfig = require('./cumo.js');

    return gulp.src(dev.src + 'cumo/pages/**/*.+(html|nunjucks|njk)')
        .pipe(data(function() {
            return cumoConfig;
        }))
        .pipe(plumber())
        .pipe(nunjucksRender({
            path: [dev.src],
            data: {
                tpl_pages: pages,
                src_icons: icons
            }
        }))
        .pipe(htmlbeautify({
            indentSize: 4,
            "max_preserve_newlines": "2"
        }))
        .pipe(gulp.dest(build.root));
});

// Html Templates
gulp.task('nunja', function () {
    return gulp.src(dev.src + 'pages/**/*.+(html|nunjucks|njk)')
        .pipe(plumber())
        .pipe(nunjucksRender({
            path: [dev.src]
        }))
        .pipe(htmlbeautify({
            indentSize: 4,
            "max_preserve_newlines": "2"
        }))
        .pipe(gulp.dest(build.root));
});

// SVG Icons
gulp.task('svg--optimization', function () {
    return gulp.src(dev.root + '/icons/**/*.+(svg)')
        .pipe(imagemin(
            imagemin.svgo({
                plugins: [
                    {removeViewBox: false},
                    {cleanupIDs: true},
                    {cleanupAttrs: true},
                    {convertStyleToAttrs: true},
                    {removeUselessStrokeAndFill: true},
                    {collapseGroups: true}
                ]
            })
        ))
        .pipe(gulp.dest(build.icons_optimized));
});

gulp.task('svg--sprite', function () {
    return gulp.src(build.icons + '/optimized/sprite/**/*.+(svg)')
        .pipe(svgSprite({
            'svg': {
                'namespaceClassnames': 'false',
                'xmlDeclaration': false,
                'doctypeDeclaration': false,
                'dimensionAttributes': false
            },
            'mode': {
                'symbol': {
                    'dest': '',
                    'example': true,
                    'sprite': 'ic-sprite.svg'
                }
            }
        }))
        .pipe(gulp.dest(build.icons));
});

gulp.task('svg--inline', function(){
    return gulp.src(build.icons + '/optimized/inline/**/*.+(svg)')
        .pipe(sassInlineSvg({
            destDir: 'dev/src/cumo/helpers'
        }));
});


gulp.task('favicon', function(){
    return gulp.src(dev.root + 'favicon/**/*')
        .pipe(gulp.dest(build.root));
});

gulp.task('img', function(){
    return gulp.src(dev.root + 'img/**/*')
        .pipe(gulpif(
            argv.prod,
            (imagemin())
        ))
        .pipe(gulp.dest(build.images));
});

gulp.task('sequence-1',  gulpSequence(['cumo', 'nunja-docs', 'nunja'], 'svg--optimization', ['svg--inline', 'svg--sprite'], 'styles', 'favicon', 'img'));

// Static Server + watching html, js, scss files
gulp.task('build', ['sequence-1'], function () {

    browserSync.init({
        server: {
            baseDir: root.build
        }
    });

    // Cumo setup
    gulp.watch('cumo.js', ['cumo', 'nunja-docs', 'nunja']);

    // Watch styles
    gulp.watch(dev.src + '**/*.scss', ['styles']);
    gulp.watch(build.styles + '**/*.css').on('change', browserSync.reload);

    // Watch templates & html
    gulp.watch(dev.src + '**/*.njk', ['nunja-docs', 'nunja']);
    gulp.watch(build.root + '**/*.html').on('change', browserSync.reload);
});